==> owncloud-10.2.0.zip: owncloud/apps/files_sharing/l10n/gl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "The mountpoint name contains invalid characters." : "O nome do punto de montaxe contén caracteres incorrectos",
    "Invalid or untrusted SSL certificate" : "Certificado SSL incorrecto ou non fiábel",
    "Could not authenticate to remote share, password might be wrong" : "Non foi pisíbel autenticar na compartición remota, o contrasinal podería ser erróneo",
    "Storage not valid" : "Almacenamento incorrecto",
    "Couldn't add remote share" : "Non foi posíbel engadir a compartición remota",
    "Shared with you" : "Compartido con vostede",
    "Shared with others" : "Compartido con outros",
    "Shared by link" : "Compartido por ligazón",
    "Uploading..." : "Enviando...",
    "Nothing shared with you yet" : "Aínda non hai nada compartido con vostede.",
    "Files and folders others share with you will show up here" : "Os ficheiros e cartafoles que outros compartan con vostede amosaranse aquí",
    "Nothing shared yet" : "Aínda non hay nada compartido",
    "Files and folders you share will show up here" : "Os ficheiros e cartafoles que comparta amosaranse aquí",
    "No shared links" : "Non hai ligazóns compartidas",
    "Files and folders you share by link will show up here" : "Os ficheiros e cartafoles que comparta por ligazón amosaranse aquí",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir a compartición remota {name} desde {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contrasinal da compartición remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "You can upload into this folder" : "Pode envialo a este cartafol",
    "No ownCloud installation (7 or higher) found at {remote}" : "Non se atopa unha instalación de ownCloud (7 ou superior) en {remote}",
    "Invalid ownCloud url" : "URL incorrecto do ownCloud",
    "Share" : "Compartir",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartindo",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartiuse</strong> un ficheiro ou cartafol",
    "A file or folder was shared from <strong>another server</strong>" : "Compartiuse un ficheiro ou cartafol desde <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Foi <strong>descargado</strong> un ficheiro ou cartafol público",
    "You received a new remote share %2$s from %1$s" : "Recibiu unha compartición remota %2$s de %1$s",
    "You received a new remote share from %s" : "Recibiu unha compartición remota de %s",
    "%1$s accepted remote share %2$s" : "%1$s comparticións remotas aceptadas %2$s",
    "%1$s declined remote share %2$s" : "%1$s comparticións remotas declinadas %2$s",
    "%1$s unshared %2$s from you" : "%1$s deixou de compartir %2$s con vostede",
    "Public shared folder %1$s was downloaded" : "Foi descargado o cartafol público %1$s",
    "Public shared file %1$s was downloaded" : "Foi descargado o ficheiro público %1$s",
    "You shared %1$s with %2$s" : "Compartiu %1$s con %2$s",
    "You shared %1$s with group %2$s" : "Compartiu %1$s co grupo %2$s",
    "You shared %1$s via link" : "Vostede compartiu %1$s mediante ligazón",
    "%2$s shared %1$s with you" : "%2$s compartiu %1$s con vostede",
    "Shares" : "Comparticións",
    "This share is password-protected" : "Esta compartición está protexida con contrasinal",
    "The password is wrong. Try again." : "O contrasinal é incorrecto. Ténteo de novo.",
    "Password" : "Contrasinal",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Name" : "Nome",
    "Share time" : "Compartir o tempo",
    "Expiration date" : "Data de caducidade",
    "Sorry, this link doesn’t seem to work anymore." : "Semella que esta ligazón non funciona.",
    "Reasons might be:" : "As razóns poderían ser:",
    "the item was removed" : "o elemento foi retirado",
    "the link expired" : "a ligazón caducou",
    "sharing is disabled" : "foi desactivada a compartición",
    "For more info, please ask the person who sent this link." : "Para obter máis información, pregúntelle á persoa que lle enviou a ligazón.",
    "Add to your ownCloud" : "Engadir ao seu ownCloud",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Ligazón directa",
    "Pending" : "Pendentes",
    "Accept" : "Aceptar",
    "Declined" : "Rexeitado",
    "Public link" : "Ligazón pública",
    "Decline" : "Declinar",
    "Share API is disabled" : "A API para compartir está desactivada",
    "Wrong share ID, share doesn't exist" : "O ID do recurso compartido non é correcto, o recurso compartido non existe",
    "Could not delete share" : "Non foi posíbel eliminar o recurso compartido",
    "Please specify a file or folder path" : "Especifique a ruta ao ficheiro ou cartafol",
    "Wrong path, file/folder doesn't exist" : "A ruta é incorrecta ou o ficheiro/cartafol non existe",
    "Please specify a valid user" : "Especifique un usuario válido",
    "Group sharing is disabled by the administrator" : "A compartición en grupo foi desactivada polo administrador.",
    "Please specify a valid group" : "Especifique un grupo válido",
    "Public link sharing is disabled by the administrator" : "A compartición de ligazóns públicas foi desactivada polo administrador.",
    "Public upload disabled by the administrator" : "O envío público foi desactivado polo administrador.",
    "Public upload is only possible for publicly shared folders" : "O envío público só é posíbel para cartafoles compartidos publicamente",
    "Invalid date, date format must be YYYY-MM-DD" : "Data incorrecta, o formato da data debe ser AAAA-MM-DD",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Fallou a compartición de %s, xa que a infraestrutura non permite accións do tipo %s",
    "Unknown share type" : "Tipo descoñecido de recurso compartido",
    "Not a directory" : "Non é un directorio",
    "Could not lock path" : "Non foi posíbel bloquear a ruta",
    "Can't change permissions for public share links" : "Non é posíbel cambiar os permisos das ligazóns de recursos compartidos públicos",
    "Wrong or no update parameter given" : "Parámetro incorrecto ou non actualizado",
    "Cannot increase permissions" : "Non é posíbel aumentar os permisos",
    "Anonymous upload" : "Envío anónimo",
    "Uploaded files" : "Ficheiros enviados",
    "Couldn't send mail to following recipient(s): %s " : "Non foi posíbel enviar o correo aos seguintes destinatarios: %s",
    "Click to select files or use drag & drop to upload" : "Prema para seleccionar ficheiros ou empregue arrastrar e soltar para enviar",
    "An error occurred while updating share state: {message}" : "Produciuse un erro ao actualizar o estado do recurso compartido: {message}",
    "Accept Share" : "Aceptar a compartición",
    "Decline Share" : "Declinar a compartición",
    "File sharing" : "Compartir ficheiros",
    "Cannot remove all permissions" : "Non é posíbel retirar todos os permisos",
    "The group is blacklisted for sharing" : "O grupo está na lista negra de compartición ",
    "Only recipient can change accepted state" : "Só o destinatario pode cambiar o estado aceptado",
    "State" : "Estado:",
    "Public link expired" : "A ligazón pública caducou",
    "Shared by %2$s" : "Compartido por %2$s",
    "Not allowed to create a federated share with the same user server" : "Non está permitido crear un recurso compartido federado co mesmo servidor de usuario",
    "No expiration date set" : "Non se estabeleceu a data de caducidade",
    "%2$s shared %1$s with %3$s" : "%2$s compartiu %1$s con %3$s",
    "You removed the share of %2$s for %1$s" : "Vostede retirou a compartición de %2$s para %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s retirou a compartición de %3$s para %1$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartiu %1$s co grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Vostede retirou a compartición do grupo %2$s para %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s retirou a compartición do grupo %3$s para %1$s",
    "%2$s shared %1$s via link" : "%2$s compartiu %1$s mediante ligazón",
    "You removed the public link for %1$s" : "Vostede retirou a ligazón pública para %1$s",
    "%2$s removed the public link for %1$s" : "%2$s retirou a ligazón pública para %1$s",
    "Your public link for %1$s expired" : "A súa ligazón pública para %1$s caducou",
    "The public link of %2$s for %1$s expired" : "A súa ligazón pública de %2$s para %1$s caducou",
    "%2$s removed the share for %1$s" : "%2$s retirou a compartición para %1$s",
    "Downloaded via public link" : "Descargado mediante ligazón pública",
    "Shared with %2$s" : "Compartido con %2$s",
    "Shared with %3$s by %2$s" : "Compartido con %3$s por %2$s",
    "Removed share for %2$s" : "Compartición retirada por %2$s",
    "%2$s removed share for %3$s" : "%2$s retirou a compartición para %3$s",
    "Shared with group %2$s" : "Compartido co grupo %2$s",
    "Shared with group %3$s by %2$s" : "Compartido co grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Retirada a compartición do grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s retirou a compartición do grupo %3$s",
    "Shared via link by %2$s" : "Compartido mediante ligazón por %2$s",
    "Shared via public link" : "Compartido mediante ligazón pública",
    "Removed public link" : "Retirada a ligazón pública",
    "%2$s removed public link" : "%2$s retirou a ligazón pública",
    "Public link of %2$s expired" : "A ligazón pública de %2$s caducou",
    "%s is publicly shared" : "%s está compartido públicamente",
    "Group Sharing Blacklist" : "Lista negra de compartición en grupo",
    "Exclude groups from receiving shares" : "Excluir grupos de recibir comparticións",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Estes grupos non estarán dispoñíbeis para compartir. Os membros do grupo non están restrinxidos ao iniciar comparticións e poden recibir comparticións con outros grupos dos que son membros como é habitual."
},
"nplurals=2; plural=(n != 1);");

==> owncloud-10.4.0.zip: owncloud/apps/files_sharing/l10n/gl.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Server to server sharing is not enabled on this server" : "Neste servidor non está activada a compartición de servidor a servidor",
    "The mountpoint name contains invalid characters." : "O nome do punto de montaxe contén caracteres incorrectos",
    "Not allowed to create a federated share with the same user server" : "Non está permitido crear un recurso compartido federado co mesmo servidor de usuario",
    "Invalid or untrusted SSL certificate" : "Certificado SSL incorrecto ou non fiábel",
    "Could not authenticate to remote share, password might be wrong" : "Non foi pisíbel autenticar na compartición remota, o contrasinal podería ser erróneo",
    "Storage not valid" : "Almacenamento incorrecto",
    "Couldn't add remote share" : "Non foi posíbel engadir a compartición remota",
    "Shared with you" : "Compartido con vostede",
    "Shared with others" : "Compartido con outros",
    "Shared by link" : "Compartido por ligazón",
    "Anonymous upload" : "Envío anónimo",
    "Click to select files or use drag & drop to upload" : "Prema para seleccionar ficheiros ou empregue arrastrar e soltar para enviar",
    "Uploaded files" : "Ficheiros enviados",
    "Uploading..." : "Enviando...",
    "Nothing shared with you yet" : "Aínda non hai nada compartido con vostede.",
    "Files and folders others share with you will show up here" : "Os ficheiros e cartafoles que outros compartan con vostede amosaranse aquí",
    "Nothing shared yet" : "Aínda non hay nada compartido",
    "Files and folders you share will show up here" : "Os ficheiros e cartafoles que comparta amosaranse aquí",
    "No shared links" : "Non hai ligazóns compartidas",
    "Files and folders you share by link will show up here" : "Os ficheiros e cartafoles que comparta por ligazón amosaranse aquí",
    "An error occurred while updating share state: {message}" : "Produciuse un erro ao actualizar o estado do recurso compartido: {message}",
    "Accept Share" : "Aceptar a compartición",
    "Decline Share" : "Declinar a compartición",
    "Do you want to add the remote share {name} from {owner}@{remote}?" : "Quere engadir a compartición remota {name} dende {owner}@{remote}?",
    "Remote share" : "Compartición remota",
    "Remote share password" : "Contrasinal da compartición remota",
    "Cancel" : "Cancelar",
    "Add remote share" : "Engadir unha compartición remota",
    "You can upload into this folder" : "Pode envialo a este cartafol",
    "No ownCloud installation (7 or higher) found at {remote}" : "Non se atopa unha instalación de ownCloud (7 ou superior) en {remote}",
    "Invalid ownCloud url" : "URL incorrecto do ownCloud",
    "Share" : "Compartir",
    "No expiration date set" : "Non se estabeleceu a data de caducidade",
    "Declined" : "Rexeitado",
    "Pending" : "Pendentes",
    "Shared by" : "Compartido por",
    "Sharing" : "Compartindo",
    "A file or folder has been <strong>shared</strong>" : "<strong>Compartiuse</strong> un ficheiro ou cartafol",
    "A file or folder was shared from <strong>another server</strong>" : "Compartiuse un ficheiro ou cartafol dende <strong>outro servidor</strong>",
    "A public shared file or folder was <strong>downloaded</strong>" : "Foi <strong>descargado</strong> un ficheiro ou cartafol público",
    "You received a new remote share %2$s from %1$s" : "Recibiu unha compartición remota %2$s de %1$s",
    "You received a new remote share from %s" : "Recibiu unha compartición remota de %s",
    "%1$s accepted remote share %2$s" : "%1$s comparticións remotas aceptadas %2$s",
    "%1$s declined remote share %2$s" : "%1$s comparticións remotas declinadas %2$s",
    "%1$s unshared %2$s from you" : "%1$s deixou de compartir %2$s con vostede",
    "Public shared folder %1$s was downloaded" : "Foi descargado o cartafol público %1$s",
    "Public shared file %1$s was downloaded" : "Foi descargado o ficheiro público %1$s",
    "You shared %1$s with %2$s" : "Compartiu %1$s con %2$s",
    "%2$s shared %1$s with %3$s" : "%2$s compartiu %1$s con %3$s",
    "You removed the share of %2$s for %1$s" : "Vostede retirou a compartición de %2$s para %1$s",
    "%2$s removed the share of %3$s for %1$s" : "%2$s retirou a compartición de %3$s para %1$s",
    "You unshared %1$s shared by %2$s from self" : "Vostede deixou o propio uso compartido de %1$s compartido por %2$s",
    "You shared %1$s with group %2$s" : "Compartiu %1$s co grupo %2$s",
    "%2$s shared %1$s with group %3$s" : "%2$s compartiu %1$s co grupo %3$s",
    "You removed the share of group %2$s for %1$s" : "Vostede retirou a compartición do grupo %2$s para %1$s",
    "%2$s removed the share of group %3$s for %1$s" : "%2$s retirou a compartición do grupo %3$s para %1$s",
    "%2$s shared %1$s via link" : "%2$s compartiu %1$s mediante ligazón",
    "You shared %1$s via link" : "Vostede compartiu %1$s mediante ligazón",
    "You removed the public link for %1$s" : "Vostede retirou a ligazón pública para %1$s",
    "%2$s removed the public link for %1$s" : "%2$s retirou a ligazón pública para %1$s",
    "Your public link for %1$s expired" : "A súa ligazón pública para %1$s caducou",
    "The public link of %2$s for %1$s expired" : "A súa ligazón pública de %2$s para %1$s caducou",
    "%2$s shared %1$s with you" : "%2$s compartiu %1$s con vostede",
    "%2$s removed the share for %1$s" : "%2$s retirou a compartición para %1$s",
    "Downloaded via public link" : "Descargado mediante ligazón pública",
    "Shared with %2$s" : "Compartido con %2$s",
    "Shared with %3$s by %2$s" : "Compartido con %3$s por %2$s",
    "Removed share for %2$s" : "Compartición retirada por %2$s",
    "%2$s removed share for %3$s" : "%2$s retirou a compartición para %3$s",
    "Unshared %1$s from self" : "Deixou o propio uso compartido de %1$s",
    "Shared with group %2$s" : "Compartido co grupo %2$s",
    "Shared with group %3$s by %2$s" : "Compartido co grupo %3$s por %2$s",
    "Removed share of group %2$s" : "Retirada a compartición do grupo %2$s",
    "%2$s removed share of group %3$s" : "%2$s retirou a compartición do grupo %3$s",
    "Shared via link by %2$s" : "Compartido mediante ligazón por %2$s",
    "Shared via public link" : "Compartido mediante ligazón pública",
    "Removed public link" : "Retirada a ligazón pública",
    "%2$s removed public link" : "%2$s retirou a ligazón pública",
    "Public link expired" : "A ligazón pública caducou",
    "Public link of %2$s expired" : "A ligazón pública de %2$s caducou",
    "Shared by %2$s" : "Compartido por %2$s",
    "Shares" : "Comparticións",
    "File sharing" : "Compartir ficheiros",
    "Public link" : "Ligazón pública",
    "Couldn't send mail to following recipient(s): %s " : "Non foi posíbel enviar o correo aos seguintes destinatarios: %s",
    "Share API is disabled" : "A API para compartir está desactivada",
    "Wrong share ID, share doesn't exist" : "O ID do recurso compartido non é correcto, o recurso compartido non existe",
    "Could not delete share" : "Non foi posíbel eliminar o recurso compartido",
    "Please specify a file or folder path" : "Especifique a ruta ao ficheiro ou cartafol",
    "Wrong path, file/folder doesn't exist" : "A ruta é incorrecta ou o ficheiro/cartafol non existe",
    "Invalid date, date format must be YYYY-MM-DD" : "Data incorrecta, o formato da data debe ser AAAA-MM-DD",
    "Please specify a valid user" : "Especifique un usuario válido",
    "Group sharing is disabled by the administrator" : "A compartición en grupo foi desactivada polo administrador.",
    "Please specify a valid group" : "Especifique un grupo válido",
    "The group is blacklisted for sharing" : "O grupo está na lista negra de compartición ",
    "Public link sharing is disabled by the administrator" : "A compartición de ligazóns públicas foi desactivada polo administrador.",
    "Public upload disabled by the administrator" : "O envío público foi desactivado polo administrador.",
    "Public upload is only possible for publicly shared folders" : "O envío público só é posíbel para cartafoles compartidos publicamente",
    "Sharing %s failed because the back end does not allow shares from type %s" : "Fallou a compartición de %s, xa que a infraestrutura non permite accións do tipo %s",
    "Unknown share type" : "Tipo descoñecido de recurso compartido",
    "Not a directory" : "Non é un directorio",
    "Could not lock path" : "Non foi posíbel bloquear a ruta",
    "Could not update share" : "Non foi posíbel actualizar o recurso compartido",
    "Can't change permissions for public share links" : "Non é posíbel cambiar os permisos das ligazóns de recursos compartidos públicos",
    "Only recipient can change accepted state" : "Só o destinatario pode cambiar o estado aceptado",
    "\"%1$s\" shared \"%3$s\" with you (on behalf of \"%2$s\")" : "%1$s compartiu «%2$s» con vostede (en nome de «%2$s»)",
    "\"%1$s\" shared \"%3$s\" with you" : "%1$s compartiu «%2$s» con vostede",
    "\"%1$s\" invited you to view \"%3$s\" (on behalf of \"%2$s\")" : "«%1$s» convidouno a ver «%3$s» (en nome de «%2$s»)",
    "\"%1$s\" invited you to view \"%3$s\"" : "«%1$s» convidouno a ver «%3$s»",
    "Accept" : "Aceptar",
    "Decline" : "Declinar",
    "Automatically accept new incoming local user shares" : "Aceptar automaticamente novas comparticións dos usuarios locais",
    "Allow finding you via autocomplete in share dialog. If this is disabled the full username needs to be entered." : "Permite atopar mediante o completado automático no diálogo de compartición. Se esta opción está desactivada, debera escribirse o nome de usuario completo. ",
    "This share is password-protected" : "Esta compartición está protexida con contrasinal",
    "The password is wrong. Try again." : "O contrasinal é incorrecto. Ténteo de novo.",
    "Password" : "Contrasinal",
    "No entries found in this folder" : "Non se atoparon entradas neste cartafol",
    "Name" : "Nome",
    "State" : "Estado:",
    "Share time" : "Compartir o tempo",
    "Expiration date" : "Data de caducidade",
    "Sorry, this link doesn’t seem to work anymore." : "Semella que esta ligazón non funciona.",
    "Reasons might be:" : "As razóns poderían ser:",
    "the item was removed" : "o elemento foi retirado",
    "the link expired" : "a ligazón caducou",
    "sharing is disabled" : "a compartición está desactivada",
    "For more info, please ask the person who sent this link." : "Para obter máis información, pregúntelle á persoa que lle enviou a ligazón.",
    "%s is publicly shared" : "%s está compartido públicamente",
    "Download" : "Descargar",
    "Download %s" : "Descargar %s",
    "Direct link" : "Ligazón directa",
    "Nothing to configure." : "Nada que configurar.",
    "Group Sharing Blacklist" : "Lista negra de compartición en grupo",
    "Exclude groups from receiving shares" : "Excluir grupos de recibir comparticións",
    "These groups will not be available to share with. Members of the group are not restricted in initiating shares and can receive shares with other groups they are a member of as usual." : "Estes grupos non estarán dispoñíbeis para compartir. Os membros do grupo non están restrinxidos ao iniciar comparticións e poden recibir comparticións con outros grupos dos que son membros como é habitual."
},
"nplurals=2; plural=(n != 1);");
